package com.ruoyi.cms.service;

import java.util.List;
import com.ruoyi.cms.domain.JobFair;

/**
 * 招聘会信息Service接口
 * 
 * @author lishundong
 * @date 2024-09-04
 */
public interface IJobFairService 
{
    /**
     * 查询招聘会信息
     * 
     * @param jobFairId 招聘会信息主键
     * @return 招聘会信息
     */
    public JobFair selectJobFairByJobFairId(Long jobFairId);

    /**
     * 查询招聘会信息列表
     * 
     * @param jobFair 招聘会信息
     * @return 招聘会信息集合
     */
    public List<JobFair> selectJobFairList(JobFair jobFair);
    /**
     * 新增招聘会信息
     *
     * @param jobFair 招聘会信息
     * @return 结果
     */
    public int insertJobFair(JobFair jobFair);

    /**
     * 修改招聘会信息
     *
     * @param jobFair 招聘会信息
     * @return 结果
     */
    public int updateJobFair(JobFair jobFair);

    /**
     * 批量删除招聘会信息
     *
     * @param jobFairIds 需要删除的招聘会信息主键集合
     * @return 结果
     */
    public int deleteJobFairByJobFairIds(Long[] jobFairIds);

    List<JobFair> appList(JobFair jobFair);

    JobFair appDetail(Long fairId);
}
